Mobile-monitoring or <U+201C>sensors on a mobile platform<U+201D>, is an increasingly
popular approach to measure high-resolution pollution data at the street level.
Coupled with location data, spatial visualisation of air-quality parameters
helps detect localized areas of high air-pollution, also called hotspots.
In this approach, portable sensors are mounted on a vehicle and driven on
predetermined routes to collect high frequency data (1 Hz). The package is
for analysing, visualising and spatial maps of high-resolution air-quality
data collected by specific devices installed on a moving platform.